% Julie Sandberg
% Aero 624 Celestial Mechanics
% Final Project
% This script defines the initial conditions of a celestial object and
% calls a Runge-Kutta routine to integrates the EOM forward in time 
% Perturbations are included in the two-body equations in 'TwoBodyPerturb'

clear all;
close all;
clc;

format long

global myu p e_vect;

myu = 3.98601e14;              % myu for Earth m/sec^2

% Define initial time
t0_days = 2455320.20833; % Julian Day Representation of May 3, 2010 at 5pm
disp('Initial Time (sec Julian):')
t0 = t0_days*(24*60*60)        % Corresponding time in seconds

% Define initial position and velocity vectors as given for assignment (m)
r0 = [6500; 0; 0]*10^3;
v0 = [0; 0.5; 7.8]*10^3;

% =========================================================================
% Part 1: Cowell's Method
% =========================================================================

% Find initial orbital elements using initial position, velocity
elements = inertial_to_orbital(r0,v0,t0);

% Need semimajor axis to calculate the period
a = elements(1);
disp('Length of Orbital Period (sec):')
Period = (2*pi)*sqrt(a^3/myu)

% Given initial time, plot position and velocity over a full
% orbital period
states0 = [r0; v0];                    % Initial position, velocity vectors

disp('Final Time is Initial Time Plus Length of One Orbital Period:')
t_final = t0 + Period
tspan = [t0 t_final];

options = optimset('TolFun',1e-100000,'TolX',1e-100000);
[t,vect1] = ode45('TwoBody',tspan,states0);     % Integrate r,v forward in time
vect1 = vect1/1000;             % Convert from meters to kilometers
    
% Calculatios for perigee location
h1 = cross(r0,v0);                                    % Angular momentum
e_vect1 = (1/myu)*(cross(v0,h1) - (myu*r0)/norm(r0)); % Eccentricity vectors
e1 = norm(e_vect1);

figure(1)
grid on
hold on
plot3(vect1(:,1),vect1(:,2),vect1(:,3),'-k')% Plot position as function of time
plot3(r0(1)/1000,r0(2)/1000,r0(3)/1000,'*g')          % Plot the initial position in green
e_hat1 = [e_vect1]/e1;                  
perigee = a*(1-e1)*e_hat1/1000;
plot3(perigee(1), perigee(2), perigee(3),'*b') % Plot the perigee in blue
% title('Position Over One Orbital Period')
xlabel('X (m)')
ylabel('Y (m)')
zlabel('Z (m)')
legend('Position','Initial Position','Perigee')

figure(2)
grid on
hold on
plot3(vect1(:,4),vect1(:,5),vect1(:,6),'-k') % Plot the initial velocity in green
plot3(v0(1)/1000,v0(2)/1000,v0(3)/1000,'*g')
% title('Velocity Over One Orbital Period')
xlabel('X (m/s)')
ylabel('Y (m/s)')
zlabel('Z (m/s)')
legend('Velocity','Initial Velocity')


% =========================================================================
% Add perturbations
% =========================================================================

% Part 1.1: Cannonball drag only
% states0 = states0./1000;                % Convert to km
t_final = t0 + 20*Period
tspan = [t0 t_final];
[t,vect1] = ode45('TwoBodyPerturb',tspan,states0,options);     % Integrate r,v forward in time
vect1 = vect1/1000;             % Convert from meters to kilometers

% Compute orbital elements as a function of time
r = vect1(:,1:3);
v = vect1(:,4:6);

for i = 1:length(r)
    elements = inertial_to_orbital(r(i,:),v(i,:),t(i));
    a_t(i) = elements(1);
    e_t(i) = elements(2);
    i_t(i) = elements(3);
    w_t(i) = elements(4);
    Omega_t(i) = elements(5);
    f_t(i) = elements(7);
end

figure(3)
grid on
hold on
plot3(vect1(:,1),vect1(:,2),vect1(:,3),'-k')% Plot position as function of time
% plot3(r0(1)/1000,r0(2)/1000,r0(3)/1000,'*g')          % Plot the initial position in green
% title('Position Over Twenty Orbital Periods')
xlabel('X (m)')
ylabel('Y (m)')
zlabel('Z (m)')
% legend('Position','Initial Position')

figure(4)
grid on
hold on
plot3(vect1(:,4),vect1(:,5),vect1(:,6),'-k') % Plot the initial velocity in green
% plot3(v0(1)/1000,v0(2)/1000,v0(3)/1000,'*g')
% title('Velocity Over Twenty Orbital Periods')
xlabel('X (m/s)')
ylabel('Y (m/s)')
zlabel('Z (m/s)')
% legend('Velocity','Initial Velocity')

% Plot orbital elements as a function of time
figure
plot(t,a_t)
ylabel('a')
xlabel('t')

figure
plot(t,i_t)
ylabel('i')
xlabel('t')

figure
plot(t,e_t)
ylabel('e')
xlabel('t')

figure
plot(t,w_t)
ylabel('w')
xlabel('t')

figure
plot(t,Omega_t)
ylabel('Omega')
xlabel('t')

figure
plot(t,f_t)
ylabel('f')
xlabel('t')

