% Julie Sandberg
% Aero 624 Celestial Mechanics
% Final Project
% This script defines the initial conditions of a celestial object and
% calls a Runge-Kutta routine to integrates the orbital elements forward in
% time

clear all;
close all;
clc;

format long

global myu r;

myu = 3.98601e14;              % myu for Earth m/sec^2

% Define initial time
t0_days = 2455320.20833; % Julian Day Representation of May 3, 2010 at 5pm
disp('Initial Time (sec Julian):')
t0 = t0_days*(24*60*60);        % Corresponding time in seconds

% Define initial position and velocity vectors as given for assignment (m)
r0 = [6500; 0; 0]*10^3;
v0 = [0; 0.5; 7.8]*10^3;

% =========================================================================
% Part 2: Calculate time-varying orbital elements using Gauss Variation of
% Parameters differential equations
% =========================================================================

% Find initial orbital elements using initial position, velocity
elements = inertial_to_orbital(r0,v0,t0);
a_t0 = elements(1);
e_t0 = elements(2);
i_t0 = elements(3);
w_t0 = elements(4);
Omega_t0 = elements(5);
% M_t0 = elements(6);
f_t0 = elements(7);

% Final Time is Initial Time Plus Length of Twenty Orbital Periods
Period = (2*pi)*sqrt(a_t0^3/myu);
t_final = t0 + 20*Period;
tspan = [t0 t_final];

% states0 = [r0' v0']';

options = optimset('TolFun',1e-1000,'TolX',1e-1000);
% [t S] = ode45('TwoBodyPerturb',tspan,states0,options);
% velocity = S(:,1:3)./1000;
% position = S(:,4:6)./1000;

% % Perturbed motion
% figure
% plot3(velocity(:,1),velocity(:,2),velocity(:,3))

% r = norm(r0)

states0 = [r0' v0' a_t0 e_t0 i_t0 w_t0 Omega_t0 f_t0]';
[t S] = ode45('orb_el_prop',tspan,states0,options);
velocity = S(:,1:3)./1000;
position = S(:,4:6)./1000;
a_t = S(:,7);
e_t = S(:,8);
i_t = S(:,9);
Omega_t = S(:,10);
w_t = S(:,11);
f_t = S(:,12);

% Perturbed motion
figure
plot3(velocity(:,1),velocity(:,2),velocity(:,3))


% Plot orbital elements as a function of time
figure
plot(t,a_t)
ylabel('a')
xlabel('t')

figure
plot(t,i_t)
ylabel('i')
xlabel('t')

figure
plot(t,e_t)
ylabel('e')
xlabel('t')

figure
plot(t,w_t)
ylabel('w')
xlabel('t')

figure
plot(t,Omega_t)
ylabel('Omega')
xlabel('t')

figure
plot(t,f_t)
ylabel('f')
xlabel('t')