% Julie Sandberg
% Aero 624 Celestial Mechanics
% Final Project
% This function propagates the time-varying orbital elements directly using
% the Gauss Variation of Parameters differential equations

function S = orb_el_prop(t,states)


global myu; 

format long

r = states(1:3);     r = double(r);
v = states(4:6);     v = double(v);

a = states(7);       a = double(a);
e = states(8);       e = double(e);
i = states(9);       i = double(i);
w = states(10);      w = double(w);
% Omega = states(11);  Omega = double(Omega);
f = states(12);      f = double(f);


% Calculate Perturbing Force for Cannonball Drag
rho = 1.225*exp(-(norm(r)-6378)/16);   rho = double(rho);
m = 70;         % kg
CD = 1.2;
A = 10;         % m^2
ad = -1/2*rho*(CD*A)*(norm(v)*v)/m;
ad1 = double(ad);
ad = ad1;

% Calculate Perturbing Force for J2 Oblateness
J2 = 1.0826e-3;         % Earth oblateness
rE = 6378;              % km
x = r(1);
y = r(2);
z = r(3);
ad2 = -(3*myu*J2*rE^2)/(2*norm(r)^7)*[x*(x^2+y^2-4*z^2); y*(x^2+y^2-4*z^2); z*(3*x^2+3*y^2-2*z^2)];
% ad = ad2

ad = ad1 + ad2;

accel = -myu*r/(norm(r))^3+ad;
accel = double(accel);


p = norm(r)*(1+e*cos(f));
theta = w+f;
h = (myu*p)^(1/2);

ar = r./norm(r);
ah = cross(r,v)/norm(cross(r,v));
atheta = cross(ah,ah);

% % Check for orthogonality
% ar_ah_dot = dot(ar,ah)
% ah_atheta_dot = dot(ah,atheta)
% atheta_ar_dot = dot(atheta,ar)

ar = norm(ar);
ah = norm(ah);
atheta = norm(atheta);

% Junkins & Schaub Equations
a_dot = 2*a^2/h*(e*sin(f)*ar+p/norm(r)*atheta);
e_dot = 1/h*(p*sin(f)*ar+((p+norm(r))*cos(f)+norm(r)*e)*atheta);
i_dot = (norm(r)*cos(theta)/h)*ah;
Omega_dot = ((norm(r)*sin(theta))/(h*sin(i)))*ah;
w_dot = 1/(h*e)*(-p*cos(f)*ar+(p+norm(r))*sin(f)*atheta)-(norm(r)*sin(theta)*cos(i))/(h*sin(i))*ah;
f_dot = h/norm(r)^2+1/(h*e)*(p*cos(f)*ar-(p+norm(r))*sin(f)*atheta);

S = [v(1) v(2) v(3) accel(1) accel(2) accel(3) a_dot e_dot i_dot w_dot Omega_dot f_dot]';

